@@ -5,7 +5,6 @@
 import os
 import re
 import lxml.etree
-import datetime
 import traceback as tb
 
 from collections import OrderedDict
@@ -43,7 +42,7 @@ def copyattr(a, b):
 class V2v3XmlWriter(BaseV3Writer):
     """ Writes an XML file with v2 constructs converted to v3"""
 
-    def __init__(self, xmlrfc, quiet=None, options=default_options, date=datetime.date.today()):
+    def __init__(self, xmlrfc, quiet=None, options=default_options, date=None):
         super(V2v3XmlWriter, self).__init__(xmlrfc, quiet=quiet, options=options, date=date)
         if not quiet is None:
             options.quiet = quiet
